Aya class

Constructors

Aya({int? id, String? arabic, String? translation, String? transliteration, String? tafseer, String? audioURL})

Properties

arabic String?
getter/setter pair
arabicIndex String
no setter
audioURL String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tafseer String?
getter/setter pair
translation String?
getter/setter pair
transliteration String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited