SurahContentModel class
Constructors
-
SurahContentModel({int? id, String? name, String? remark, List<
Aya> ? aya}) -
SurahContentModel.fromJson(Map<
String, dynamic> json)
Properties
- arabicIndex → String
-
no setter
-
aya
↔ List<
Aya> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- nameTranslation ↔ String?
-
getter/setter pair
- remark ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tafseer ↔ String?
-
getter/setter pair
- translationLang ↔ String?
-
getter/setter pair
- transliterationLang ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAyaTafseer(
List< String> ayaTafseer) → void -
setAyaTranslation(
List< String> ayaTranslation) → void -
setAyaTransliteration(
List< String> ayaTransliteration) → void -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited